@@ -26,12 +26,6 @@
 #define INET6_ADDRSTRLEN 46
 #endif
 
-/** Length of IPv4/v6 address string */
-#ifdef HAVE_INET6
-#define NET_ADDRSTRLEN INET6_ADDRSTRLEN
-#else
-#define NET_ADDRSTRLEN INET_ADDRSTRLEN
-#endif
 
 /* forward declarations */
 struct sa;
@@ -79,6 +73,7 @@ int net_if_getlinklocal(const char *ifname, int af, struct sa *ip);
 
 /* Net interface (ifaddrs.c) */
 int net_getifaddrs(net_ifaddr_h *ifh, void *arg);
+int net_netlink_addrs(net_ifaddr_h *ifh, void *arg);
 
 
 /* Net route */
